@@ -16,7 +16,7 @@ use RPi::Pin;
 use RPi::SPI;
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '2.3614';
+our $VERSION = '2.3615';
 
 my $fatal_exit = 1;
 
@@ -98,6 +98,7 @@ sub adc {
 }
 sub dac {
     my ($self, %args) = @_;
+    $args{model} = 'MCP4922' if ! defined $args{model};
     my $dac = RPi::DAC::MCP4922->new(%args);
     return $dac;
 }
@@ -146,7 +147,6 @@ sub spi {
 }
 sub shift_register {
     my ($self, $base, $num_pins, $data, $clk, $latch) = @_;
-
     $self->shift_reg_setup($base, $num_pins, $data, $clk, $latch);
 }
 
@@ -154,7 +154,8 @@ sub shift_register {
 
 sub _fatal_exit {
     my $self = shift;
-    $fatal_exit = $self->{fatal_exit} if defined $self->{fatal_exit};
+    $self->{fatal_exit} if defined $self->{fatal_exit};
+    return $self->{fatal_exit};
 }
 sub _setup {
     return $_[0]->{setup};
@@ -490,13 +491,15 @@ Mandatory, Integer. C<0> or C<1> for the Pi's onboard hardware CS/SS CE0 and CE1
 pins, or any GPIO number above C<1> in order to use an arbitrary GPIO pin for
 the CS pin, and we'll do the bit-banging of the SPI bus automatically.
 
-=head2 dac()
+=head2 dac(model => 'MCP4922')
 
 Returns a L<RPi::DAC::MCP4922> object (supports all 49x2 series DACs). These
 chips provide analog output signals from the Pi's digital output. Please
 see the documentation of that module for further information on both the
 configuration and use of the DAC object.
 
+Note that if the C<model> parameter is not sent in, we default to C<MCP4922>.
+
 =head2 bmp()
 
 Returns a L<RPi::BMP180> object, which allows you to return the
