@@ -7,7 +7,7 @@ use parent 'WiringPi::API';
 
 use RPi::WiringPi::Constant qw(:all);
 
-our $VERSION = '2.3614';
+our $VERSION = '2.3615';
 
 sub gpio_layout {
     return $_[0]->gpio_layout;
@@ -76,7 +76,7 @@ sub pin_scheme {
 sub pwm_range {
     my ($self, $range) = @_;
     if (defined $range){
-       $self->{pwm_range} = $range;
+        $self->{pwm_range} = $range;
         $self->pwm_set_range($range);
     }
     return defined $self->{pwm_range} ? $self->{pwm_range} : 1023;
@@ -90,7 +90,6 @@ sub unexport_pin {
     system "sudo", "gpio", "unexport", $self->pin_to_gpio($pin);
 }
 sub registered_pins {
-    my ($self, $env) = @_;
     return $ENV{RPI_PINS};
 }
 sub register_pin {
@@ -98,7 +97,8 @@ sub register_pin {
 
     my $gpio_num = $self->pin_to_gpio($pin->num);
 
-    if (defined $ENV{RPI_PINS} && grep {$gpio_num == $_} split /,/, $ENV{RPI_PINS}){
+    my @pi_env_pins = split /,/, $ENV{RPI_PINS};
+    if (defined $ENV{RPI_PINS} && grep {$gpio_num == $_} @pi_env_pins){
         die "\npin $pin is already in use... can't re-register it\n";
     }
 
@@ -131,8 +131,9 @@ sub cleanup{
     for (split /,/, $pins){
         `gpio -g mode $_ in`;
         `gpio -g mode $_ tri`;
-        delete $ENV{RPI_PINS};
     }
+
+    delete $ENV{RPI_PINS};
 }
 sub _vim{1;};
 1;
